@@ -72,7 +72,7 @@ Object* Monomial::createMono(const Operator& o) const
 {
     Operator::OperatorType mult = o.multiplicityOperator();
     
-    Object* toAdd=0;
+    Object* toAdd=nullptr;
     if(first==0.)
         delete second;
     else if(first==1.)
@@ -126,7 +126,7 @@ Monomial::Monomial(const Operator& o, Object* o2, bool& sign)
                     first = sc->value();
                     second = cx->m_params[var];
                     
-                    cx->m_params[var]=0;
+                    cx->m_params[var]=nullptr;
                     delete cx;
                     
                     ismono=true;
@@ -156,7 +156,7 @@ Monomial::Monomial(const Operator& o, Object* o2, bool& sign)
             }
         } else if(cx->firstOperator()==Operator::minus && cx->isUnary()) {
             *this = Monomial(o, *cx->firstValue(), sign);
-            *cx->firstValue()=0;
+            *cx->firstValue()=nullptr;
             delete cx;
             ismono=true;
                 
@@ -228,12 +228,12 @@ Polynomial::Polynomial(Apply* c)
     }
     
     first = true;
-    for(iterator it=monos.begin(), itEnd=monos.end(); it!=itEnd; ++it, first=false) {
+    for(auto it=monos.begin(), itEnd=monos.end(); it!=itEnd; ++it, first=false) {
         if(m_operator==Operator::minus && !first)
             it->first*=-1;
     }
     
-    for(iterator it=monos.begin(), itEnd=monos.end(); it!=itEnd; ++it, first=false)
+    for(auto it=monos.begin(), itEnd=monos.end(); it!=itEnd; ++it, first=false)
         addMonomial(*it);
     
     simpScalars(firstValue);
@@ -247,7 +247,7 @@ void Polynomial::addMonomial(const Monomial& m)
     }
     
     bool found = false;
-    QList<Monomial>::iterator it1(begin());
+    auto it1(begin());
     for(; it1!=end(); ++it1) {
         Object *o1=it1->second, *o2=m.second;
         found = AnalitzaUtils::equalTree(o1, o2);
@@ -270,16 +270,16 @@ void Polynomial::addMonomial(const Monomial& m)
 
 void Polynomial::simpScalars(bool firstValue)
 {
-    Object *value=0;
+    Object *value=nullptr;
     if(!firstValue && m_operator==Operator::minus && !m_scalars.isEmpty())
         m_scalars.first() = negateObject(m_scalars.first());
 
-    for(QList<Object*>::const_iterator i=m_scalars.constBegin(); i!=m_scalars.constEnd(); ++i) {
+    for(auto i=m_scalars.constBegin(); i!=m_scalars.constEnd(); ++i) {
         bool d=false;
         
         Object* aux = simpExpression(*i);
         if(value) {
-            QString* err=0;
+            QString* err=nullptr;
             value=Operations::reduce(m_operator.operatorType(), value, aux, &err);
             d=err;
             delete err;
@@ -288,7 +288,7 @@ void Polynomial::simpScalars(bool firstValue)
         
         if(d) {
             addValue(aux);
-            value=0;
+            value=nullptr;
         }
     }
     
@@ -319,14 +319,14 @@ void Polynomial::addValue(Object* value)
 
 Object* Polynomial::toObject()
 {
-    Object* root = 0;
+    Object* root = nullptr;
     if(count()==1) {
         root = first().createMono(m_operator);
     } else if(count()>1) {
         Apply* c = new Apply;
         c->appendBranch(new Operator(m_operator));
         
-        QList<Monomial>::iterator i=begin();
+        auto i=begin();
         bool first=true;
         for(; i!=end(); ++i, first=false) {
             if(!first && m_operator==Operator::minus)
