@@ -20,22 +20,22 @@
 #ifndef BUILTINTEST_H
 #define BUILTINTEST_H
 
-#include <QtCore/QObject>
+#include <QObject>
 #include <analyzer.h>
 
 class BuiltInTest : public QObject
 {
-	Q_OBJECT
-	public:
-		BuiltInTest(QObject* parent = 0);
-		~BuiltInTest();
-		
-	private Q_SLOTS:
-		void testCall();
-		void testCall_data();
-		
-	private:
-		Analitza::Analyzer a;
+    Q_OBJECT
+    public:
+        BuiltInTest(QObject* parent = nullptr);
+        ~BuiltInTest();
+        
+    private Q_SLOTS:
+        void testCall();
+        void testCall_data();
+        
+    private:
+        Analitza::Analyzer a;
 };
 
 #endif // BUILTINTEST_H
