@@ -20,7 +20,7 @@
 #include "mathmlpresentationlexer.h"
 #include "expressionparser.h"
 #include "expression.h"
-#include <QtTest/QTest>
+#include <QTest>
 #include <QtTest>
 
 using Analitza::Expression;
