@@ -31,7 +31,7 @@ VariablesModel::VariablesModel(const QSharedPointer<Variables>& v, QObject *pare
 {}
 
 VariablesModel::VariablesModel(QObject* parent)
-    : QAbstractTableModel(parent), m_vars(0), m_editable(true)
+    : QAbstractTableModel(parent), m_vars(nullptr), m_editable(true)
 {}
 
 void VariablesModel::setVariables(const QSharedPointer<Variables> &v)
@@ -58,8 +58,8 @@ QVariant VariablesModel::data(const QModelIndex & index, int role) const
         } else
             ret=m_vars->value(key)->toString();
     } else if(role==Qt::WhatsThisRole && index.column()==0) {
-        ret = QStringLiteral("%1:=%2").arg(index.sibling(index.row(), 0).data(Qt::DisplayRole).toString(),
-                                           index.sibling(index.row(), 1).data(Qt::DisplayRole).toString());
+        ret = QStringLiteral("%1 := %2").arg(index.sibling(index.row(), 0).data(Qt::DisplayRole).toString(),
+                                             index.sibling(index.row(), 1).data(Qt::DisplayRole).toString());
     }
     return ret;
 }
