@@ -267,6 +267,8 @@ void Plotter3DES::setModel(QAbstractItemModel* f)
 {
     m_model = f;
 
+    if (m_model)
+        updatePlots(QModelIndex(), 0, m_model->rowCount()-1);
     modelChanged();
 }
 
@@ -507,6 +509,7 @@ bool Plotter3DES::save(const QUrl& url)
         exportSurfaces(path);
     } else if(path.endsWith(QLatin1String(".pdf"))) {
         auto px = grabImage();
+//this pulls widgets
         QPrinter printer;
         printer.setOutputFormat(QPrinter::PdfFormat);
         printer.setOutputFileName(path);
