@@ -20,7 +20,10 @@
 #include <QQuickWindow>
 #include <QOpenGLFramebufferObject>
 #include <analitzaplot/plotsmodel.h>
-#include <QThread>
+#include <QTimer>
+#include <QQuickItemGrabResult>
+#include <QGuiApplication>
+#include <QElapsedTimer>
 
 using namespace Analitza;
 
@@ -31,8 +34,7 @@ Plotter3DRenderer::Plotter3DRenderer(Graph3DItem* item)
 
 void Plotter3DRenderer::renderGL()
 {
-    Q_ASSERT(QThread::currentThread() == m_item->thread());
-    m_item->update();
+    QTimer::singleShot(0, m_item, &Graph3DItem::update);
 }
 
 QQuickWindow* Plotter3DRenderer::window() const
@@ -48,15 +50,13 @@ Graph3DItem::Graph3DItem(QQuickItem* parent)
     m_plotter->setUseSimpleRotation(true);
     setModel(new PlotsModel(this));
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
     setMirrorVertically(true);
-#endif
 }
 
 Graph3DItem::~Graph3DItem()
 {}
 
-QStringList Graph3DItem::addFunction(const QString& expression, Analitza::Variables* vars)
+QStringList Graph3DItem::addFunction(const QString& expression, const QSharedPointer<Analitza::Variables>& vars)
 {
     PlotsModel* plotsmodel = qobject_cast<PlotsModel*>(m_plotter->model());
     if(!plotsmodel)
@@ -73,7 +73,8 @@ QAbstractItemModel* Graph3DItem::model() const
 
 void Graph3DItem::setModel(QAbstractItemModel* model)
 {
-    disconnect(m_plotter->model(), 0, this, 0);
+    if (m_plotter->model())
+        disconnect(m_plotter->model(), nullptr, this, nullptr);
 
     m_plotter->setModel(model);
 
@@ -98,9 +99,19 @@ void Graph3DItem::scale(qreal s)
     m_plotter->scale(s);
 }
 
-void Graph3DItem::resetView()
+void Graph3DItem::resetViewport()
 {
-    m_plotter->resetView();
+    m_plotter->resetViewport();
+}
+
+bool Graph3DItem::save(const QUrl& url)
+{
+    return m_plotter->save(url);
+}
+
+QStringList Graph3DItem::filters() const
+{
+    return m_plotter->filters();
 }
 
 class Plotter3DFboRenderer : public QQuickFramebufferObject::Renderer
@@ -133,3 +144,18 @@ QQuickFramebufferObject::Renderer* Graph3DItem::createRenderer() const
     m_plotter->setViewport(QRectF({0,0}, QSizeF(width(), height())));
     return new Plotter3DFboRenderer(m_plotter);
 }
+
+QImage Plotter3DRenderer::grabImage()
+{
+    QSharedPointer<QQuickItemGrabResult> imgGrab = m_item->grabToImage();
+    QImage ret;
+    connect(imgGrab.data(), &QQuickItemGrabResult::ready, this, [imgGrab, &ret]() {
+        ret = imgGrab->image();
+    });
+    QElapsedTimer timer;
+    timer.start();
+    while(ret.size().isEmpty() && timer.elapsed()<2000) {
+        qGuiApp->processEvents();
+    }
+    return ret;
+}
